@@ -1,21 +1,20 @@
 import copy
 import dataclasses
 import logging
-import re
-from collections import defaultdict, namedtuple
-from typing import Any, Dict, List, Tuple, Union
+from collections import defaultdict
+from typing import Any, Dict, List, Union
 
 from oarepo_model_builder.builders import process
 from oarepo_model_builder.builders.python import PythonBuilder
 from oarepo_model_builder.datatypes import Import, datatypes
 from oarepo_model_builder.schema import ModelSchema
 from oarepo_model_builder.stack.stack import ModelBuilderStack
-from oarepo_model_builder.utils.camelcase import camel_case
 from oarepo_model_builder.utils.jinja import (
     split_base_name,
     split_package_base_name,
     split_package_name,
 )
+from oarepo_model_builder.utils.python_name import convert_name_to_python
 from oarepo_model_builder.validation import InvalidModelException
 
 from .invenio_base import InvenioBaseClassPythonBuilder
@@ -76,9 +75,7 @@ class MarshmallowNode:
     @classmethod
     def _kwargs(cls, definition: Any, schema: ModelSchema, stack: ModelBuilderStack):
         field_name = definition.get("field-name", stack.top.key)
-        field_name = field_name.replace("-", "_")
-        field_name = re.sub("\W", "", field_name)
-        field_name = re.sub("^[^a-zA-Z_]+", "", field_name)
+        field_name = convert_name_to_python(field_name)
         return {
             "read": definition.get("read", True),
             "write": definition.get("write", True),
@@ -144,7 +141,6 @@ class MarshmallowNode:
 
 @dataclasses.dataclass
 class CompositeMarshmallowNode(MarshmallowNode):
-
     fields: List["MarshmallowNode"] = dataclasses.field(default_factory=list)
 
     @classmethod
@@ -178,6 +174,7 @@ class ObjectMarshmallowNode(CompositeMarshmallowNode):
     generate: bool = True
     schema_class: Union[str, None] = None
     base_classes: Union[List[str], None] = None
+    extra_fields: Union[List[Dict[str, str]], None] = None
 
     @classmethod
     def _kwargs(cls, definition: Any, schema: ModelSchema, stack: ModelBuilderStack):
@@ -185,6 +182,7 @@ class ObjectMarshmallowNode(CompositeMarshmallowNode):
             "generate": definition.get("generate", True),
             "schema_class": definition.get("schema-class", None),
             "base_classes": definition.get("base-classes", ["ma.Schema"]),
+            "extra_fields": definition.get("extra-fields", []),
             **super()._kwargs(definition, schema, stack),
         }
 
@@ -211,6 +209,9 @@ class ObjectMarshmallowNode(CompositeMarshmallowNode):
             return None, None, None
 
         field_list = []
+        for fld in self.extra_fields:
+            field_list.append(f"{fld.name} = {fld.value}")
+
         for fld in self.fields:
             if fld.read or fld.write:
                 # and generate the field
