@@ -4,14 +4,14 @@ from oarepo_model_builder.builder import ModelBuilder
 from oarepo_model_builder.builders.mapping import MappingBuilder
 from oarepo_model_builder.datatypes import datatypes
 from oarepo_model_builder.fs import InMemoryFileSystem
-from oarepo_model_builder.model_preprocessors.default_values import \
-    DefaultValuesModelPreprocessor
+from oarepo_model_builder.model_preprocessors.default_values import (
+    DefaultValuesModelPreprocessor,
+)
 from oarepo_model_builder.outputs.mapping import MappingOutput
 from oarepo_model_builder.outputs.python import PythonOutput
 from oarepo_model_builder.schema import ModelSchema
 from oarepo_model_builder.validation.model_validation import model_validator
-from tests.multilang import (MultilangPreprocessor, MultilingualDataType,
-                             UIValidator)
+from tests.multilang import MultilangPreprocessor, MultilingualDataType, UIValidator
 
 try:
     import json5
@@ -123,3 +123,92 @@ def test_mapping_preprocessor():
             }
         }
     }
+
+
+def test_no_index():
+    model = {"properties": {"a": {"type": "keyword", "facets": {"searchable": False}}}}
+    data = build_model(model)
+
+    assert data == {
+        "mappings": {"properties": {"a": {"type": "keyword", "index": False}}}
+    }
+
+
+def test_no_index_on_model():
+    model = {"properties": {"a": {"type": "keyword"}}, "searchable": False}
+    data = build_model(model)
+
+    assert data == {
+        "mappings": {"properties": {"a": {"type": "keyword", "index": False}}}
+    }
+
+
+def test_override_no_index_on_model():
+    model = {
+        "properties": {"a": {"type": "keyword", "facets": {"searchable": True}}},
+        "searchable": False,
+    }
+    data = build_model(model)
+
+    assert data == {"mappings": {"properties": {"a": {"type": "keyword"}}}}
+
+
+def test_override_no_index_on_model():
+    model = {
+        "properties": {"a": {"type": "keyword", "facets": {"searchable": True}}},
+        "searchable": False,
+    }
+    data = build_model(model)
+
+    assert data == {"mappings": {"properties": {"a": {"type": "keyword"}}}}
+
+
+def test_deep_no_index():
+    model = {
+        "properties": {
+            "a": {
+                "type": "object",
+                "facets": {"searchable": False},
+                "properties": {"b": {"type": "keyword"}},
+            }
+        }
+    }
+    data = build_model(model)
+
+    assert data == {
+        "mappings": {
+            "properties": {
+                "a": {
+                    "properties": {"b": {"type": "keyword", "index": False}},
+                    "type": "object",
+                    "index": False,
+                }
+            }
+        }
+    }
+
+
+def test_deep_no_index_children():
+    model = {
+        "properties": {
+            "a": {
+                "type": "object",
+                "properties": {
+                    "b": {"type": "keyword", "facets": {"searchable": False}}
+                },
+            }
+        }
+    }
+    data = build_model(model)
+
+    assert data == {
+        "mappings": {
+            "properties": {
+                "a": {
+                    "properties": {"b": {"type": "keyword", "index": False}},
+                    "type": "object",
+                    "index": False,
+                }
+            }
+        }
+    }
