@@ -3,24 +3,28 @@ import os
 
 from oarepo_model_builder.builder import ModelBuilder
 from oarepo_model_builder.builders.model_saver import (
-    ModelRegistrationBuilder, ModelSaverBuilder)
+    ModelRegistrationBuilder,
+    ModelSaverBuilder,
+)
 from oarepo_model_builder.datatypes import datatypes
 from oarepo_model_builder.entrypoints import (
-    load_entry_points_dict, load_included_models_from_entry_points)
+    load_entry_points_dict,
+    load_included_models_from_entry_points,
+)
 from oarepo_model_builder.fs import InMemoryFileSystem
-from oarepo_model_builder.model_preprocessors.default_values import \
-    DefaultValuesModelPreprocessor
-from oarepo_model_builder.model_preprocessors.invenio import \
-    InvenioModelPreprocessor
+from oarepo_model_builder.model_preprocessors.default_values import (
+    DefaultValuesModelPreprocessor,
+)
+from oarepo_model_builder.model_preprocessors.invenio import InvenioModelPreprocessor
 from oarepo_model_builder.outputs.cfg import CFGOutput
 from oarepo_model_builder.outputs.json import JSONOutput
 from oarepo_model_builder.outputs.python import PythonOutput
-from oarepo_model_builder.property_preprocessors.datatype_preprocessor import \
-    DataTypePreprocessor
+from oarepo_model_builder.property_preprocessors.datatype_preprocessor import (
+    DataTypePreprocessor,
+)
 from oarepo_model_builder.schema import ModelSchema
 from oarepo_model_builder.validation.model_validation import model_validator
-from tests.multilang import (MultilangPreprocessor, MultilingualDataType,
-                             UIValidator)
+from tests.multilang import MultilingualDataType, UIValidator
 
 try:
     import json5
@@ -180,6 +184,7 @@ def test_model_saver():
             "record-schema-metadata-class": "test.services.records.schema.TestMetadataSchema",
             "record-prefix": "Test",
             "proxies-current-service": "test.proxies.current_service",
+            "permissions": {"presets": []},
             "record-services-package": "test.services.records",
         }
     }
@@ -280,32 +285,35 @@ def test_model_saver_invenio():
                     },
                     "type": "keyword",
                     "sample": {"skip": True},
+                    "facets": {"searchable": True},
                 },
                 "created": {
                     "marshmallow": {
                         "write": False,
                         "read": True,
                         "field-class": "ma_fields.String",
-                        "validators": ["validate_date('%Y:%m:%d')"],
+                        "validators": ["validate_date('%Y-%m-%d')"],
                         "imports": [
                             {"import": "oarepo_runtime.validation.validate_date"}
                         ],
                     },
                     "type": "date",
                     "sample": {"skip": True},
+                    "facets": {"searchable": True},
                 },
                 "updated": {
                     "marshmallow": {
                         "write": False,
                         "read": True,
                         "field-class": "ma_fields.String",
-                        "validators": ["validate_date('%Y:%m:%d')"],
+                        "validators": ["validate_date('%Y-%m-%d')"],
                         "imports": [
                             {"import": "oarepo_runtime.validation.validate_date"}
                         ],
                     },
                     "type": "date",
                     "sample": {"skip": True},
+                    "facets": {"searchable": True},
                 },
                 "$schema": {
                     "marshmallow": {
@@ -317,6 +325,7 @@ def test_model_saver_invenio():
                     },
                     "type": "keyword",
                     "sample": {"skip": True},
+                    "facets": {"searchable": True},
                 },
             },
             "config-resource-register-blueprint-key": "TEST_REGISTER_BLUEPRINT",
@@ -384,5 +393,6 @@ def test_model_saver_invenio():
             "config-service-config-key": "TEST_SERVICE_CONFIG_TEST",
             "invenio-record-schema-extra-code": "",
             "flask-commands-setup-cfg": "test",
+            "permissions": {"presets": []},
         }
     }
