@@ -1,12 +1,9 @@
 import json
 import os
 import re
-from pathlib import Path
 
-from oarepo_model_builder.entrypoints import (create_builder_from_entrypoints,
-                                              load_model)
+from oarepo_model_builder.entrypoints import create_builder_from_entrypoints, load_model
 from oarepo_model_builder.fs import InMemoryFileSystem
-from tests.utils import assert_python_equals
 
 
 def test_raw_type():
@@ -44,8 +41,8 @@ from oarepo_runtime.validation import validate_date
 class TestSchema(InvenioBaseRecordSchema):
     \"""TestSchema schema.\"""
     a = ma_fields.Raw()
-    created = ma_fields.String(validate=[validate_date('%Y:%m:%d')], dump_only=True)
-    updated = ma_fields.String(validate=[validate_date('%Y:%m:%d')], dump_only=True)
+    created = ma_fields.String(validate=[validate_date('%Y-%m-%d')], dump_only=True)
+    updated = ma_fields.String(validate=[validate_date('%Y-%m-%d')], dump_only=True)
     """,
     )
 
