@@ -1,14 +1,11 @@
 import json
 import os
 import re
-from pathlib import Path
 
 import yaml
 
-from oarepo_model_builder.entrypoints import (create_builder_from_entrypoints,
-                                              load_model)
+from oarepo_model_builder.entrypoints import create_builder_from_entrypoints, load_model
 from oarepo_model_builder.fs import InMemoryFileSystem
-from tests.utils import assert_python_equals
 
 
 def test_array_shortcuts():
@@ -51,8 +48,8 @@ from oarepo_runtime.validation import validate_date
 class TestSchema(InvenioBaseRecordSchema):
     \"""TestSchema schema.\"""
     a = ma_fields.List(ma_fields.String())        
-    created = ma_fields.String(validate=[validate_date('%Y:%m:%d')], dump_only=True)
-    updated = ma_fields.String(validate=[validate_date('%Y:%m:%d')], dump_only=True)
+    created = ma_fields.String(validate=[validate_date('%Y-%m-%d')], dump_only=True)
+    updated = ma_fields.String(validate=[validate_date('%Y-%m-%d')], dump_only=True)
     """,
     )
 
@@ -64,9 +61,7 @@ class TestSchema(InvenioBaseRecordSchema):
         "mappings": {
             "properties": {
                 "$schema": {"type": "keyword"},
-                "a": {
-                    "type": "keyword",
-                },
+                "a": {"type": "keyword"},
                 "created": {"type": "date"},
                 "id": {"type": "keyword"},
                 "updated": {"type": "date"},
